% Auto-generated chapter 4 for abudawud
% Hadiths in this chapter: 52

\hadithdefcmd{abudawud}{1198}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ فُرِضَتِ الصَّلاَةُ رَكْعَتَيْنِ رَكْعَتَيْنِ فِي الْحَضَرِ وَالسَّفَرِ فَأُقِرَّتْ صَلاَةُ السَّفَرِ وَزِيدَ فِي صَلاَةِ الْحَضَرِ ‏.‏\hadithno{1198}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (350) Sahih Muslim (685)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The prayer was prescribed as consisting of two rak'ahs both when one was resident and when travelling. The prayer while travelling was left according to the original prescription and the prayer of one who was resident was enhanced}}
\hadithdefcmd{abudawud}{1199}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنَا خُشَيْشٌ، - يَعْنِي ابْنَ أَصْرَمَ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي عَمَّارٍ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَيْهِ، عَنْ يَعْلَى بْنِ أُمَيَّةَ، قَالَ قُلْتُ لِعُمَرَ بْنِ الْخَطَّابِ أَرَأَيْتَ إِقْصَارَ النَّاسِ الصَّلاَةَ وَإِنَّمَا قَالَ تَعَالَى ‏\{‏ إِنْ خِفْتُمْ أَنْ يَفْتِنَكُمُ الَّذِينَ كَفَرُوا ‏\}‏ فَقَدْ ذَهَبَ ذَلِكَ الْيَوْمُ ‏.‏ فَقَالَ عَجِبْتُ مِمَّا عَجِبْتَ مِنْهُ فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ صَدَقَةٌ تَصَدَّقَ اللَّهُ بِهَا عَلَيْكُمْ فَاقْبَلُوا صَدَقَتَهُ ‏"‏ ‏.‏\hadithno{1199}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim (686)}\hadithtrans{Narrated Ya'la b. Umayyah:I remarked to 'Umar al-Khattab: Have you seen the shortening of the prayer by the people today while Allah has said: "If you fear that those who are infidels may afflict you", whereas those days are gone now? He replied: I have wondered about the same matter for which you wondered. So I mentioned this to the Messenger of Allah (ﷺ). He said: It is an act of charity which Allah has done to you, so accept his charity}}
\hadithdefcmd{abudawud}{1200}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، وَمُحَمَّدُ بْنُ بَكْرٍ، قَالاَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي عَمَّارٍ، يُحَدِّثُ فَذَكَرَهُ نَحْوَهُ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أَبُو عَاصِمٍ وَحَمَّادُ بْنُ مَسْعَدَةَ كَمَا رَوَاهُ ابْنُ بَكْرٍ ‏.‏\hadithno{1200}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The above mentioned tradition has also been narrated through a different chain of transmitters by 'Abd Allah b. Abi 'Ammar who narrated it in like manner. Abu Dawud said:This has been transmitted by Abu 'Asim and Hammad b. Mas'adah as transmitted by Ibn Bakr}}
\hadithdefcmd{abudawud}{1201}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ يَحْيَى بْنِ يَزِيدَ الْهُنَائِيِّ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ عَنْ قَصْرِ الصَّلاَةِ، فَقَالَ أَنَسٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا خَرَجَ مَسِيرَةَ ثَلاَثَةِ أَمْيَالٍ أَوْ ثَلاَثَةِ فَرَاسِخَ - شُعْبَةُ شَكَّ - يُصَلِّي رَكْعَتَيْنِ ‏.‏\hadithno{1201}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (691)}\hadithtrans{Narrated Yahya b. Yazid al-Hannani:I asked Anas b. Malik about the shortening of the prayer (while travelling). He said: When the Messenger of Allah (ﷺ) went out on a journey of three miles or three farsakh (the narrator Shu'bah doubted), he used to pray two rak'ahs}}
\hadithdefcmd{abudawud}{1202}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَإِبْرَاهِيمَ بْنِ مَيْسَرَةَ، سَمِعَا أَنَسَ بْنَ مَالِكٍ، يَقُولُ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الظُّهْرَ بِالْمَدِينَةِ أَرْبَعًا وَالْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ ‏.‏\hadithno{1202}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1089) Sahih Muslim (690)}\hadithtrans{Narrated Anas b. Malik :I prayed along with the Messenger of Allah (ﷺ) four rak'ahs at the noon prayer at Medina and two rak'ahs at the afternoon prayer in Dhu al-Hulaifah}}
\hadithdefcmd{abudawud}{1203}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّ أَبَا عُشَّانَةَ الْمَعَافِرِيَّ، حَدَّثَهُ عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَعْجَبُ رَبُّكُمْ مِنْ رَاعِي غَنَمٍ فِي رَأْسِ شَظِيَّةٍ بِجَبَلٍ يُؤَذِّنُ بِالصَّلاَةِ وَيُصَلِّي فَيَقُولُ اللَّهُ عَزَّ وَجَلَّ انْظُرُوا إِلَى عَبْدِي هَذَا يُؤَذِّنُ وَيُقِيمُ الصَّلاَةَ يَخَافُ مِنِّي فَقَدْ غَفَرْتُ لِعَبْدِي وَأَدْخَلْتُهُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{1203}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Uqbah ibn Amir: I heard the Messenger of Allah (ﷺ) say: Allah is pleased with a shepherd of goats who calls to prayer at the peak of a mountain, and offers prayer, Allah, the Exalted, says: Look at this servant of Mine; he calls to prayer and offers it and he fears Me. So I forgive him and admit him to paradise}}
\hadithdefcmd{abudawud}{1204}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الْمِسْحَاجِ بْنِ مُوسَى، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ حَدِّثْنَا مَا، سَمِعْتَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ كُنَّا إِذَا كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي السَّفَرِ فَقُلْنَا زَالَتِ الشَّمْسُ أَوْ لَمْ تَزُلْ صَلَّى الظُّهْرَ ثُمَّ ارْتَحَلَ ‏.‏\hadithno{1204}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mishaj b. Musa:I asked Anas b. Malik: Narrate to us what you heard the Messenger of Allah (ﷺ) say. He said: When we travelled along with the Messenger of Allah (ﷺ), we would say: Did the sun pass the meridian or not? But he (the Prophet) would offer the noon prayer and then proceed}}
\hadithdefcmd{abudawud}{1205}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي حَمْزَةُ الْعَائِذِيُّ، - رَجُلٌ مِنْ بَنِي ضَبَّةَ - قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا نَزَلَ مَنْزِلاً لَمْ يَرْتَحِلْ حَتَّى يُصَلِّيَ الظُّهْرَ فَقَالَ لَهُ رَجُلٌ وَإِنْ كَانَ بِنِصْفِ النَّهَارِ قَالَ وَإِنْ كَانَ بِنِصْفِ النَّهَارِ ‏.‏\hadithno{1205}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: When the Messenger of Allah (ﷺ) halted at a certain place (while on a journey), he would not leave that place till he offered the noon prayer. A man said to him: Even if in the middle of the day? He replied: Even if in the middle of the day}}
\hadithdefcmd{abudawud}{1206}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ أَبِي الطُّفَيْلِ، عَامِرِ بْنِ وَاثِلَةَ أَنَّ مُعَاذَ بْنَ جَبَلٍ، أَخْبَرَهُمْ أَنَّهُمْ، خَرَجُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجْمَعُ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ فَأَخَّرَ الصَّلاَةَ يَوْمًا ثُمَّ خَرَجَ فَصَلَّى الظُّهْرَ وَالْعَصْرَ جَمِيعًا ثُمَّ دَخَلَ ثُمَّ خَرَجَ فَصَلَّى الْمَغْرِبَ وَالْعِشَاءَ جَمِيعًا ‏.‏\hadithno{1206}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (706)}\hadithtrans{Narrated Mu’adh bin Jabal :They (the Companions) proceeded on the expedition of Tabuk along with the Messenger of Allah (ﷺ). He combined the noon and afternoon prayers and the sunset and night prayers. One day he delayed the prayer and came out (of his dwelling) and combined the noon and the afternoon prayers. He then went it and then came out and combined the sunset and the night prayers}}
\hadithdefcmd{abudawud}{1207}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، اسْتُصْرِخَ عَلَى صَفِيَّةَ وَهُوَ بِمَكَّةَ فَسَارَ حَتَّى غَرَبَتِ الشَّمْسُ وَبَدَتِ النُّجُومُ فَقَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا عَجِلَ بِهِ أَمْرٌ فِي سَفَرٍ جَمَعَ بَيْنَ هَاتَيْنِ الصَّلاَتَيْنِ ‏.‏ فَسَارَ حَتَّى غَابَ الشَّفَقُ فَنَزَلَ فَجَمَعَ بَيْنَهُمَا ‏.‏\hadithno{1207}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: Ibn Umar was informed about the death of Safiyyah (the wife of the Prophet) when he was at Mecca. He proceeded till the sun set and the stars shined. He said: When the Prophet (ﷺ) was in a hurry about something while on a journey, he would combine both these prayers. He proceed till twilight had disappeared. He then combined both of them (the prayers)}}
\hadithdefcmd{abudawud}{1208}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الرَّمْلِيُّ الْهَمْدَانِيُّ، حَدَّثَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، وَاللَّيْثُ بْنُ سَعْدٍ، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ أَبِي الطُّفَيْلِ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ فِي غَزْوَةِ تَبُوكَ إِذَا زَاغَتِ الشَّمْسُ قَبْلَ أَنْ يَرْتَحِلَ جَمَعَ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَإِنْ يَرْتَحِلْ قَبْلَ أَنْ تَزِيغَ الشَّمْسُ أَخَّرَ الظُّهْرَ حَتَّى يَنْزِلَ لِلْعَصْرِ وَفِي الْمَغْرِبِ مِثْلَ ذَلِكَ إِنْ غَابَتِ الشَّمْسُ قَبْلَ أَنْ يَرْتَحِلَ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ وَإِنْ يَرْتَحِلْ قَبْلَ أَنْ تَغِيبَ الشَّمْسُ أَخَّرَ الْمَغْرِبَ حَتَّى يَنْزِلَ لِلْعِشَاءِ ثُمَّ جَمَعَ بَيْنَهُمَا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ هِشَامُ بْنُ عُرْوَةَ عَنْ حُسَيْنِ بْنِ عَبْدِ اللَّهِ عَنْ كُرَيْبٍ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ الْمُفَضَّلِ وَاللَّيْثِ ‏.‏\hadithno{1208}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Mu'adh ibn Jabal: On the expedition to Tabuk if the sun had passed the meridian before the apostle of Allah (ﷺ) moved off, he combined the noon and the afternoon prayers; but if he moved off before the sun had passed the meridian, he delayed the noon prayer till he halted for the afternoon prayer. He acted similarly for the sunset prayer; if the sun set before he moved off, he combined the sunset and the night prayers, but if he moved off before sunset, he delayed the sunset prayer till he halted for the night prayer and then combined them. Abu Dawud said: Hisham b. 'Urwah narrated this tradition from Husain b. 'Abd Allah, from Kuraib on the authority of Ibn 'Abbas from the Prophet (ﷺ) like the tradition narrated by Mufaddal and al-Laith}}
\hadithdefcmd{abudawud}{1209}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، عَنْ أَبِي مَوْدُودٍ، عَنْ سُلَيْمَانَ بْنِ أَبِي يَحْيَى، عَنِ ابْنِ عُمَرَ، قَالَ مَا جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ قَطُّ فِي السَّفَرِ إِلاَّ مَرَّةً ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا يُرْوَى عَنْ أَيُّوبَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ مَوْقُوفًا عَلَى ابْنِ عُمَرَ أَنَّهُ لَمْ يُرَ ابْنُ عُمَرَ جَمَعَ بَيْنَهُمَا قَطُّ إِلاَّ تِلْكَ اللَّيْلَةَ يَعْنِي لَيْلَةَ اسْتُصْرِخَ عَلَى صَفِيَّةَ وَرُوِيَ مِنْ حَدِيثِ مَكْحُولٍ عَنْ نَافِعٍ أَنَّهُ رَأَى ابْنَ عُمَرَ فَعَلَ ذَلِكَ مَرَّةً أَوْ مَرَّتَيْنِ ‏.‏\hadithno{1209}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Umar: The Messenger of Allah (ﷺ) never combined the sunset and night prayers while on a journey except once. Abu Dawud said: This has been narrated by Ayyub from Nafi' from Ibn 'Umar as a statement of Ibn 'Umar. Ibn 'Umar was never seen combining these two prayers except on the night he was informed about the death of Safiyyah. The tradition narrated by Makhul from Nafi' indicates that he (Nafi') saw Ibn 'Umar doing so once or twice}}
\hadithdefcmd{abudawud}{1210}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ وَالْعَصْرَ جَمِيعًا وَالْمَغْرِبَ وَالْعِشَاءَ جَمِيعًا فِي غَيْرِ خَوْفٍ وَلاَ سَفَرٍ ‏.‏ قَالَ مَالِكٌ أُرَى ذَلِكَ كَانَ فِي مَطَرٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ حَمَّادُ بْنُ سَلَمَةَ نَحْوَهُ عَنْ أَبِي الزُّبَيْرِ وَرَوَاهُ قُرَّةُ بْنُ خَالِدٍ عَنْ أَبِي الزُّبَيْرِ قَالَ فِي سَفْرَةٍ سَافَرْنَاهَا إِلَى تَبُوكَ ‏.‏\hadithno{1210}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (705)}\hadithtrans{Narrated 'Abd Allah b. 'Abbas: The Messenger of Allah (ﷺ) combined the noon and the afternoon prayers, and combined the sunset and night prayers without any danger or journey. Malik said: I think it so happened during rain. Abu Dawud said: Hammad b. Salamah narrated it like manner from Abu al-Zubair, it has also been narrated by Qurrah b. Khalid from Abu al-Zubair. He said: It is so happened in a journey that we made to Tabuk}}
\hadithdefcmd{abudawud}{1211}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ بِالْمَدِينَةِ مِنْ غَيْرِ خَوْفٍ وَلاَ مَطَرٍ ‏.‏ فَقِيلَ لاِبْنِ عَبَّاسٍ مَا أَرَادَ إِلَى ذَلِكَ قَالَ أَرَادَ أَنْ لاَ يُحْرِجَ أُمَّتَهُ ‏.‏\hadithno{1211}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (705 After  706)}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) combined the noon and afternoon prayers, and the sunset and night prayers at Medina without any danger and rain. He was asked: What did he intend by it ? He replied: He intended that his community might not fall into hardship}}
\hadithdefcmd{abudawud}{1212}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ وَاقِدٍ، أَنَّ مُؤَذِّنَ ابْنِ عُمَرَ، قَالَ الصَّلاَةُ ‏.‏ قَالَ سِرْ سِرْ ‏.‏ حَتَّى إِذَا كَانَ قَبْلَ غُيُوبِ الشَّفَقِ نَزَلَ فَصَلَّى الْمَغْرِبَ ثُمَّ انْتَظَرَ حَتَّى غَابَ الشَّفَقُ وَصَلَّى الْعِشَاءَ ثُمَّ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا عَجِلَ بِهِ أَمْرٌ صَنَعَ مِثْلَ الَّذِي صَنَعْتُ فَسَارَ فِي ذَلِكَ الْيَوْمِ وَاللَّيْلَةِ مَسِيرَةَ ثَلاَثٍ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ جَابِرٍ عَنْ نَافِعٍ نَحْوَ هَذَا بِإِسْنَادِهِ ‏.‏\hadithno{1212}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Waqid: The mu'adhdhin of Ibn Umar said: prayer (i.e. the time of prayer has come). He said: Go ahead. He then alighted before the disappearance. He then offered the night prayer. He then said: When the Messenger of Allah (ﷺ) was in a hurry about something, he would do as I did. Then he travelled and covered a distance of three days' journey on the day. Abu Dawud said: A similar tradition has been transmitted by Ibn Jabir from Nafi' with the same chain}}
\hadithdefcmd{abudawud}{1213}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، عَنِ ابْنِ جَابِرٍ، بِهَذَا الْمَعْنَى ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ عَبْدُ اللَّهِ بْنُ الْعَلاَءِ عَنْ نَافِعٍ، قَالَ حَتَّى إِذَا كَانَ عِنْدَ ذَهَابِ الشَّفَقِ نَزَلَ فَجَمَعَ بَيْنَهُمَا ‏.‏\hadithno{1213}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{This tradition has also been transmitted by Ibrahim b. Musa al-Razi, from 'Isa, on the authority of Ibn Jabir to the same effect. Abu Dawud said:'Abd Allah b. al-'Ala' narrated on the authority of Nafi' saying: When the twilight was about to disappear, he alighted and combined both (the prayers)}}
\hadithdefcmd{abudawud}{1214}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ ثَمَانِيًا وَسَبْعًا الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ ‏.‏ وَلَمْ يَقُلْ سُلَيْمَانُ وَمُسَدَّدٌ بِنَا ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ صَالِحٌ مَوْلَى التَّوْأَمَةِ عَنِ ابْنِ عَبَّاسٍ قَالَ فِي غَيْرِ مَطَرٍ ‏.‏\hadithno{1214}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (543) Sahih Muslim (705)}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) led us in prayer at Medina eight of seven rak'ahs, in the noon and afternoon prayers, and the sunset and night prayers. The narrator Sulaiman and Musaddad did not say the words "led us". Abu Dawud said: The aforesaid tradition has also been narrated by Salih, the client of Tu'mah on the authority if Ibn 'Abbas saying: "Not during rain}}
\hadithdefcmd{abudawud}{1215}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا يَحْيَى بْنُ مُحَمَّدٍ الْجَارِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَابَتْ لَهُ الشَّمْسُ بِمَكَّةَ فَجَمَعَ بَيْنَهُمَا بِسَرِفَ ‏.‏\hadithno{1215}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: When the sun set at Mecca, the Messenger of Allah (ﷺ) combined the two prayers at Sarif}}
\hadithdefcmd{abudawud}{1216}{حَدَّثَنَا مُحَمَّدُ بْنُ هِشَامٍ، جَارُ أَحْمَدَ بْنِ حَنْبَلٍ حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، عَنْ هِشَامِ بْنِ سَعْدٍ، قَالَ بَيْنَهُمَا عَشْرَةُ أَمْيَالٍ يَعْنِي بَيْنَ مَكَّةَ وَسَرِفَ ‏.‏\hadithno{1216}\hadithgrade{Al-Albani: Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hisham b. Sa'd:There was a distance of ten miles between them, that is, Mecca and Sarif}}
\hadithdefcmd{abudawud}{1217}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبٍ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ اللَّيْثِ، قَالَ قَالَ رَبِيعَةُ - يَعْنِي كَتَبَ إِلَيْهِ - حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ قَالَ غَابَتِ الشَّمْسُ وَأَنَا عِنْدَ عَبْدِ اللَّهِ بْنِ عُمَرَ فَسِرْنَا فَلَمَّا رَأَيْنَاهُ قَدْ أَمْسَى قُلْنَا الصَّلاَةُ ‏.‏ فَسَارَ حَتَّى غَابَ الشَّفَقُ وَتَصَوَّبَتِ النُّجُومُ ثُمَّ إِنَّهُ نَزَلَ فَصَلَّى الصَّلاَتَيْنِ جَمِيعًا ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا جَدَّ بِهِ السَّيْرُ صَلَّى صَلاَتِي هَذِهِ يَقُولُ يَجْمَعُ بَيْنَهُمَا بَعْدَ لَيْلٍ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عَاصِمُ بْنُ مُحَمَّدٍ عَنْ أَخِيهِ عَنْ سَالِمٍ وَرَوَاهُ ابْنُ أَبِي نَجِيحٍ عَنْ إِسْمَاعِيلَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ذُؤَيْبٍ أَنَّ الْجَمْعَ بَيْنَهُمَا مِنِ ابْنِ عُمَرَ كَانَ بَعْدَ غُيُوبِ الشَّفَقِ ‏.‏\hadithno{1217}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Umar: Abdullah ibn Dinar said: The sun set when I was with Abdullah ibn Umar. We proceeded, and when we saw that the evening came, we said prayer. He went on travelling until the twilight disappeared and the stars became thick. He then slighted and combined the two prayers. Then he said: I saw the Messenger of Allah (ﷺ); when he hastened his travelling, he would pray like this prayer of mine. He said: He would combine the two prayers after the passing of a part of night. AbuDawud said: This has been transmitted by Asim ibn Muhammad from his brother on the authority of Salim and this has also been narrated by Ibn AbuNajih from Isma'il ibn AbdurRahman ibn Dhuwayb saying that Ibn Umar would combine the two prayers after the disappearance of twilight}}
\hadithdefcmd{abudawud}{1218}{حَدَّثَنَا قُتَيْبَةُ، وَابْنُ، مَوْهَبٍ - الْمَعْنَى - قَالاَ حَدَّثَنَا الْمُفَضَّلُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ارْتَحَلَ قَبْلَ أَنْ تَزِيغَ الشَّمْسُ أَخَّرَ الظُّهْرَ إِلَى وَقْتِ الْعَصْرِ ثُمَّ نَزَلَ فَجَمَعَ بَيْنَهُمَا فَإِنْ زَاغَتِ الشَّمْسُ قَبْلَ أَنْ يَرْتَحِلَ صَلَّى الظُّهْرَ ثُمَّ رَكِبَ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ مُفَضَّلٌ قَاضِيَ مِصْرَ وَكَانَ مُجَابَ الدَّعْوَةِ وَهُوَ ابْنُ فَضَالَةَ ‏.‏\hadithno{1218}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1112) Sahih Muslim (704)}\hadithtrans{Narrated Anas b. Malik :When the Messenger of Allah (ﷺ) proceeded before the sun had declined, he delayed the noon prayer till the time of the afternoon prayer, he would then alight and combine the two prayers. If the sun declined before he moved off, he would offer the noon prayer and rode (the beast) - may peace be upon him. Abu Dawud said: The narrator Mufaddal was the judge of Egypt. His supplication was accepted by Allah; he was the son of Fudalah}}
\hadithdefcmd{abudawud}{1219}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي جَابِرُ بْنُ إِسْمَاعِيلَ، عَنْ عُقَيْلٍ، بِهَذَا الْحَدِيثِ بِإِسْنَادِهِ قَالَ وَيُؤَخِّرُ الْمَغْرِبَ حَتَّى يَجْمَعَ بَيْنَهَا وَبَيْنَ الْعِشَاءِ حِينَ يَغِيبُ الشَّفَقُ ‏.‏\hadithno{1219}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1112) Sahih Muslim (704)}\hadithtrans{The above mentioned tradition has also been reported by 'Uqail through a different chain of narrators. He said:He would delay the evening prayer till he combined the evening and the night prayers when the twilight disappeared}}
\hadithdefcmd{abudawud}{1220}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الطُّفَيْلِ، عَامِرِ بْنِ وَاثِلَةَ عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ فِي غَزْوَةِ تَبُوكَ إِذَا ارْتَحَلَ قَبْلَ أَنْ تَزِيغَ الشَّمْسُ أَخَّرَ الظُّهْرَ حَتَّى يَجْمَعَهَا إِلَى الْعَصْرِ فَيُصَلِّيهِمَا جَمِيعًا وَإِذَا ارْتَحَلَ بَعْدَ زَيْغِ الشَّمْسِ صَلَّى الظُّهْرَ وَالْعَصْرَ جَمِيعًا ثُمَّ سَارَ وَكَانَ إِذَا ارْتَحَلَ قَبْلَ الْمَغْرِبِ أَخَّرَ الْمَغْرِبَ حَتَّى يُصَلِّيَهَا مَعَ الْعِشَاءِ وَإِذَا ارْتَحَلَ بَعْدَ الْمَغْرِبِ عَجَّلَ الْعِشَاءَ فَصَلاَّهَا مَعَ الْمَغْرِبِ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَمْ يَرْوِ هَذَا الْحَدِيثَ إِلاَّ قُتَيْبَةُ وَحْدَهُ ‏.‏\hadithno{1220}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Mu'adh ibn Jabal: The Prophet (ﷺ) was engaged in the Battle of Tabuk. If he moved off before the sun had declined, he would delay the noon prayer till he would combine it with the afternoon prayer and would offer them together. If he moved off after the sun had declined, he would combine the noon and afternoon prayers, and then he proceeded; if he moved off before the evening prayer, he would delay the evening prayer; he would offer it along with the night prayer, he would delay the evening prayer; he would offer it along with the night prayer. If he moved off after the evening prayer, he would offer the night prayer earlier and offer it along with the evening prayer. Abu Dawud said: This tradition has not been narrated by anyone except by Qutaibah}}
\hadithdefcmd{abudawud}{1221}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَصَلَّى بِنَا الْعِشَاءَ الآخِرَةَ فَقَرَأَ فِي إِحْدَى الرَّكْعَتَيْنِ بِالتِّينِ وَالزَّيْتُونِ ‏.‏\hadithno{1221}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (767) Sahih Muslim (464)}\hadithtrans{Narrated Al-Bara' :We went out on a journey along with the Messenger of Allah (ﷺ). He led us in the night prayer and he recited in one of the rak'ahs: "By the fig and the olive}}
\hadithdefcmd{abudawud}{1222}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ أَبِي بُسْرَةَ الْغِفَارِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ الأَنْصَارِيِّ، قَالَ صَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ثَمَانِيَةَ عَشَرَ سَفَرًا فَمَا رَأَيْتُهُ تَرَكَ رَكْعَتَيْنِ إِذَا زَاغَتِ الشَّمْسُ قَبْلَ الظُّهْرِ ‏.‏\hadithno{1222}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Bara' ibn Azib: I accompanied the Messenger of Allah (ﷺ) on eighteen journeys and I never saw him fail to pray two rak'ahs when the sun had passed the meridian before offering the noon prayer}}
\hadithdefcmd{abudawud}{1223}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا عِيسَى بْنُ حَفْصِ بْنِ عَاصِمِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، عَنْ أَبِيهِ، قَالَ صَحِبْتُ ابْنَ عُمَرَ فِي طَرِيقٍ - قَالَ - فَصَلَّى بِنَا رَكْعَتَيْنِ ثُمَّ أَقْبَلَ فَرَأَى نَاسًا قِيَامًا فَقَالَ مَا يَصْنَعُ هَؤُلاَءِ قُلْتُ يُسَبِّحُونَ ‏.‏ قَالَ لَوْ كُنْتُ مُسَبِّحًا أَتْمَمْتُ صَلاَتِي يَا ابْنَ أَخِي إِنِّي صَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي السَّفَرِ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ حَتَّى قَبَضَهُ اللَّهُ عَزَّ وَجَلَّ وَصَحِبْتُ أَبَا بَكْرٍ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ حَتَّى قَبَضَهُ اللَّهُ عَزَّ وَجَلَّ وَصَحِبْتُ عُمَرَ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ حَتَّى قَبَضَهُ اللَّهُ تَعَالَى وَصَحِبْتُ عُثْمَانَ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ حَتَّى قَبَضَهُ اللَّهُ تَعَالَى وَقَدْ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ ‏\}‏ ‏.‏\hadithno{1223}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1102) Sahih Muslim (689)}\hadithtrans{Narrated Hafs b. 'Asim:I accompanied Ibn 'Umar on the way (on a journey). He led us in two rak'ah's of (the noon) prayer. Then he proceeded and saw some people standing. He asked: What are they doing ? I replied: They are glorifying Allah (i.e. offering supererogatory prayer). He said: If I had offered the supererogatory prayer (while travelling), I would have completed prayer, my cousin. I accompanied the Messenger of Allah (ﷺ) during the journey, he did not pray more than two raka'at until his death. I also accompanied Abu Bakr, and he prayed two raka'at and nothing more until he died. I also accompanied 'Umar, and he prayed two raka'at and nothing more until he died. I also accompanied 'Uthman, and he prayed two raka'at and nothing more until he died. Indeed Allah, the Exalted, said: "Certainly you have in the Messenger of Allah an excellent exemplar}}
\hadithdefcmd{abudawud}{1224}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسَبِّحُ عَلَى الرَّاحِلَةِ أَىَّ وَجْهٍ تَوَجَّهَ وَيُوتِرُ عَلَيْهَا غَيْرَ أَنَّهُ لاَ يُصَلِّي الْمَكْتُوبَةَ عَلَيْهَا ‏.‏\hadithno{1224}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1098) Sahih Muslim (700)}\hadithtrans{Narrated Ibn 'Umar:While travelling the Messenger of Allah (ﷺ) would pray voluntary prayer on his riding beast in whatever direction it turned; and he would observe witr prayer, but he did not offer the obligatory prayers upon it}}
\hadithdefcmd{abudawud}{1225}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا رِبْعِيُّ بْنُ عَبْدِ اللَّهِ بْنِ الْجَارُودِ، حَدَّثَنِي عَمْرُو بْنُ أَبِي الْحَجَّاجِ، حَدَّثَنِي الْجَارُودُ بْنُ أَبِي سَبْرَةَ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَافَرَ فَأَرَادَ أَنْ يَتَطَوَّعَ اسْتَقْبَلَ بِنَاقَتِهِ الْقِبْلَةَ فَكَبَّرَ ثُمَّ صَلَّى حَيْثُ وَجَّهَهُ رِكَابُهُ ‏.‏\hadithno{1225}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: When the Messenger of Allah (ﷺ) was on a journey and wished to say voluntary prayer, he made his she-camel face the qiblah and uttered the takbir (Allah is most great), then prayed in whatever direction his mount made his face}}
\hadithdefcmd{abudawud}{1226}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِي الْحُبَابِ، سَعِيدِ بْنِ يَسَارٍ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى حِمَارٍ وَهُوَ مُتَوَجِّهٌ إِلَى خَيْبَرَ ‏.‏\hadithno{1226}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (700)}\hadithtrans{Narrated 'Abd Allah b. 'Umar:I saw the Messenger of Allah (ﷺ) praying on a donkey while he was facing Khaibar}}
\hadithdefcmd{abudawud}{1227}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، - قَالَ - بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَاجَةٍ قَالَ فَجِئْتُ وَهُوَ يُصَلِّي عَلَى رَاحِلَتِهِ نَحْوَ الْمَشْرِقِ وَالسُّجُودُ أَخْفَضُ مِنَ الرُّكُوعِ ‏.‏\hadithno{1227}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (540)}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) sent me on some business, and when I came to him he was praying on (the back of) his riding beast (moving) towards the east and making the prostration lower than the bowing}}
\hadithdefcmd{abudawud}{1228}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، عَنِ النُّعْمَانِ بْنِ الْمُنْذِرِ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، أَنَّهُ سَأَلَ عَائِشَةَ - رضى الله عنها - هَلْ رُخِّصَ لِلنِّسَاءِ أَنْ يُصَلِّينَ عَلَى الدَّوَابِّ قَالَتْ لَمْ يُرَخَّصْ لَهُنَّ فِي ذَلِكَ فِي شِدَّةٍ وَلاَ رَخَاءٍ ‏.‏ قَالَ مُحَمَّدٌ هَذَا فِي الْمَكْتُوبَةِ ‏.‏\hadithno{1228}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Ata' ibn AbuRabah asked Aisha: Can women offer prayer on a riding beast? She replied: They were not permitted to do so in hardship or comfort. Muhammad ibn Shu'ayb said: This (prohibition) applies to the obligatory prayers}}
\hadithdefcmd{abudawud}{1229}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا ابْنُ عُلَيَّةَ، - وَهَذَا لَفْظُهُ - أَخْبَرَنَا عَلِيُّ بْنُ زَيْدٍ، عَنْ أَبِي نَضْرَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَشَهِدْتُ مَعَهُ الْفَتْحَ فَأَقَامَ بِمَكَّةَ ثَمَانِيَ عَشْرَةَ لَيْلَةً لاَ يُصَلِّي إِلاَّ رَكْعَتَيْنِ وَيَقُولُ ‏ "‏ يَا أَهْلَ الْبَلَدِ صَلُّوا أَرْبَعًا فَإِنَّا قَوْمٌ سَفْرٌ ‏"‏ ‏.‏\hadithno{1229}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Imran ibn Husayn: I went on an expedition with the Messenger of Allah (ﷺ), and I was present with him at the conquest. He stayed eighteen days in Mecca and prayed only two rak'ahs (at each time of prayer). And he said: You who live in the town must pray four; we are travellers}}
\hadithdefcmd{abudawud}{1230}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - الْمَعْنَى وَاحِدٌ - قَالاَ حَدَّثَنَا حَفْصٌ، عَنْ عَاصِمٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقَامَ سَبْعَ عَشْرَةَ بِمَكَّةَ يَقْصُرُ الصَّلاَةَ ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَمَنْ أَقَامَ سَبْعَ عَشْرَةَ قَصَرَ وَمَنْ أَقَامَ أَكْثَرَ أَتَمَّ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ عَبَّادُ بْنُ مَنْصُورٍ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ قَالَ أَقَامَ تِسْعَ عَشْرَةَ ‏.‏\hadithno{1230}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1080)}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) had a stop of seventeen days in Mecca and he shortened the prayer (i.e. prayed two rak'ahs at each time of prayer). Ibn Abbas said: He who stays seventeen days should shorten the prayer; and who stays more than that should offer complete prayer. Abu Dawud said: The other version transmitted by Ibn 'Abbas through a different chain adds: He (the Prophet) had a stop of nineteen days (in Mecca)}}
\hadithdefcmd{abudawud}{1231}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَكَّةَ عَامَ الْفَتْحِ خَمْسَ عَشْرَةَ يَقْصُرُ الصَّلاَةَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ عَبْدَةُ بْنُ سُلَيْمَانَ وَأَحْمَدُ بْنُ خَالِدٍ الْوَهْبِيُّ وَسَلَمَةُ بْنُ الْفَضْلِ عَنِ ابْنِ إِسْحَاقَ لَمْ يَذْكُرُوا فِيهِ ابْنَ عَبَّاسٍ ‏.‏\hadithno{1231}\hadithgrade{Al-Albani: Daif Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Daif Munkar; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) stayed fifteen days in Mecca in the year of Conquest. Shortening the prayer. Abu Dawud said: This tradition has also been transmitted by 'Abdah b. Sulaiman, Ahmad b. Khalid al-Wahbi, and Salamah b. Fadli on the authority of Ibn Ishaq ; but they did not mention the name of Ibn 'Abbas}}
\hadithdefcmd{abudawud}{1232}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنِي أَبِي، حَدَّثَنَا شَرِيكٌ، عَنِ ابْنِ الأَصْبَهَانِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقَامَ بِمَكَّةَ سَبْعَ عَشْرَةَ يُصَلِّي رَكْعَتَيْنِ ‏.‏\hadithno{1232}\hadithgrade{Al-Albani: Daif Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Daif Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) stayed in Mecca seventeen days and prayed two rak'ahs (at each time of prayer)}}
\hadithdefcmd{abudawud}{1233}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا وُهَيْبٌ، حَدَّثَنِي يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْمَدِينَةِ إِلَى مَكَّةَ فَكَانَ يُصَلِّي رَكْعَتَيْنِ حَتَّى رَجَعْنَا إِلَى الْمَدِينَةِ فَقُلْنَا هَلْ أَقَمْتُمْ بِهَا شَيْئًا قَالَ أَقَمْنَا بِهَا عَشْرًا ‏.‏\hadithno{1233}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1081) Sahih Muslim (693)}\hadithtrans{Narrated Anas b. Malik :We went out from Medina to Mecca with the Messenger of Allah (ﷺ) and he prayed two rak'ahs (at each time of prayer) till we returned to Medina. We (the people) said: Did you stay there for some time ? He replied: We stayed there ten days}}
\hadithdefcmd{abudawud}{1234}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَابْنُ الْمُثَنَّى، - وَهَذَا لَفْظُ ابْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، - قَالَ ابْنُ الْمُثَنَّى - قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عُمَرَ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ عَلِيًّا، - رضى الله عنه - كَانَ إِذَا سَافَرَ سَارَ بَعْدَ مَا تَغْرُبُ الشَّمْسُ حَتَّى تَكَادَ أَنْ تُظْلِمَ ثُمَّ يَنْزِلُ فَيُصَلِّي الْمَغْرِبَ ثُمَّ يَدْعُو بِعَشَائِهِ فَيَتَعَشَّى ثُمَّ يُصَلِّي الْعِشَاءَ ثُمَّ يَرْتَحِلُ وَيَقُولُ هَكَذَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏ قَالَ عُثْمَانُ عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عُمَرَ بْنِ عَلِيٍّ سَمِعْتُ أَبَا دَاوُدَ يَقُولُ وَرَوَى أُسَامَةُ بْنُ زَيْدٍ عَنْ حَفْصِ بْنِ عُبَيْدِ اللَّهِ يَعْنِي ابْنَ أَنَسِ بْنِ مَالِكٍ أَنَّ أَنَسًا كَانَ يَجْمَعُ بَيْنَهُمَا حِينَ يَغِيبُ الشَّفَقُ وَيَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم يَصْنَعُ ذَلِكَ وَرِوَايَةُ الزُّهْرِيِّ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلُهُ ‏.‏\hadithno{1234}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ali ibn AbuTalib ; Anas ibn Malik: Muhammad reported from his father, Umar, on the authority of his grandfather, Ali ibn AbuTalib: When Ali travelled, he continued to travel till it became nearly dark. He then alighted and offered the sunset prayer. Then he would call for his dinner and eat it. Then he prayed the night prayer and then moved off. He would say: This is how the Messenger of Allah (ﷺ) used to do. Usamah ibn Zayd reported from Hafs ibn Ubaydullah, the son of Anas ibn Malik: Anas would combine them (the evening and night prayer) when the twilight disappeared. He said: The Prophet (ﷺ) used to do so. Az-Zuhri also reported similarly on the authority of Anas from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1235}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِتَبُوكَ عِشْرِينَ يَوْمًا يَقْصُرُ الصَّلاَةَ ‏.‏ قَالَ أَبُو دَاوُدَ غَيْرُ مَعْمَرٍ لاَ يُسْنِدُهُ ‏.‏\hadithno{1235}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) stayed at Tabuk twenty days; he shortened the prayer (during his stay). Abu Dawud said: No one narrates this tradition with continuous chain except Ma'mar}}
\hadithdefcmd{abudawud}{1236}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي عَيَّاشٍ الزُّرَقِيِّ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِعُسْفَانَ وَعَلَى الْمُشْرِكِينَ خَالِدُ بْنُ الْوَلِيدِ فَصَلَّيْنَا الظُّهْرَ فَقَالَ الْمُشْرِكُونَ لَقَدْ أَصَبْنَا غِرَّةً لَقَدْ أَصَبْنَا غَفْلَةً لَوْ كُنَّا حَمَلْنَا عَلَيْهِمْ وَهُمْ فِي الصَّلاَةِ فَنَزَلَتْ آيَةُ الْقَصْرِ بَيْنَ الظُّهْرِ وَالْعَصْرِ فَلَمَّا حَضَرَتِ الْعَصْرُ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُسْتَقْبِلَ الْقِبْلَةِ وَالْمُشْرِكُونَ أَمَامَهُ فَصَفَّ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَفٌّ وَصَفَّ بَعْدَ ذَلِكَ الصَّفِّ صَفٌّ آخَرُ فَرَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَكَعُوا جَمِيعًا ثُمَّ سَجَدَ وَسَجَدَ الصَّفُّ الَّذِينَ يَلُونَهُ وَقَامَ الآخَرُونَ يَحْرُسُونَهُمْ فَلَمَّا صَلَّى هَؤُلاَءِ السَّجْدَتَيْنِ وَقَامُوا سَجَدَ الآخَرُونَ الَّذِينَ كَانُوا خَلْفَهُمْ ثُمَّ تَأَخَّرَ الصَّفُّ الَّذِي يَلِيهِ إِلَى مَقَامِ الآخَرِينَ وَتَقَدَّمَ الصَّفُّ الأَخِيرُ إِلَى مَقَامِ الصَّفِّ الأَوَّلِ ثُمَّ رَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَكَعُوا جَمِيعًا ثُمَّ سَجَدَ وَسَجَدَ الصَّفُّ الَّذِي يَلِيهِ وَقَامَ الآخَرُونَ يَحْرُسُونَهُمْ فَلَمَّا جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالصَّفُّ الَّذِي يَلِيهِ سَجَدَ الآخَرُونَ ثُمَّ جَلَسُوا جَمِيعًا فَسَلَّمَ عَلَيْهِمْ جَمِيعًا فَصَلاَّهَا بِعُسْفَانَ وَصَلاَّهَا يَوْمَ بَنِي سُلَيْمٍ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى أَيُّوبُ وَهِشَامٌ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ هَذَا الْمَعْنَى عَنِ النَّبِيِّ صلى الله عليه وسلم وَكَذَلِكَ رَوَاهُ دَاوُدُ بْنُ حُصَيْنٍ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ وَكَذَلِكَ عَبْدُ الْمَلِكِ عَنْ عَطَاءٍ عَنْ جَابِرٍ وَكَذَلِكَ قَتَادَةُ عَنِ الْحَسَنِ عَنْ حِطَّانَ عَنْ أَبِي مُوسَى فِعْلَهُ وَكَذَلِكَ عِكْرِمَةُ بْنُ خَالِدٍ عَنْ مُجَاهِدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَكَذَلِكَ هِشَامُ بْنُ عُرْوَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ قَوْلُ الثَّوْرِيِّ ‏.‏\hadithno{1236}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuAyyash az-Zuraqi: We accompanied the Messenger of Allah (ﷺ) at Usfan, and Khalid ibn al-Walid was the chief of unbelievers. We offered the noon prayer. Thereupon, the unbelievers said: We suffered from negligence; we became careless. We should have attacked them while they were praying. Thereupon the verse was revealed, relating to the shortening of the prayer (in time of danger) between the noon and afternoon (prayer). When the time of the afternoon prayer came, the Messenger of Allah (ﷺ) stood facing the qiblah, and the unbelievers were standing in front of him. The people stood in a row behind the Messenger of Allah (ﷺ) and there was another row behind this row. The Messenger of Allah (ﷺ) bowed and all of them bowed. He then prostrated and also the row near him prostrated. The other people in the second row remained standing and stood guard over them. When they performed two prostrations and stood up, those who were behind them prostrated. The people in the front row near him then stepped backward taking the place of the people in the second row and the second row took the place of the first row. The Messenger of Allah (ﷺ) then bowed and all of them bowed together. Then he and the row near him prostrated themselves. The other people in the second row remained standing and stood guard over them. When the Messenger of Allah (ﷺ) and the row near him (i.e. the front row) were seated, the people in the second row behind them prostrated themselves. Then all of them were seated. (He (the Prophet) then uttered the salutation upon all of them. He prayed in his manner at Usfan as well as at the territory of Banu Sulaym. Abu Dawud said: This tradition has been narrated by Ayyub and Hisham from Abu al-Zubair on the authority of Jabir to the same effect from the Prophet (ﷺ). Similarly, this has been transmitted by Dawud b. Husain from 'Ikrimah, on the authority of Ibn 'Abbas. This has also been reported by 'Abd al-Malik, from 'Ata' from Jabir in like manner. This has also been narrated by Qatadah from al-Hasan from Hittan on the authority of Abu Musa in a similar way. Similarly, this has been reported by 'Ikrimah b. Khalid from Mujahid from the Prophet (ﷺ). This has also been reported by Hisham b. 'Urwah from his father from the Prophet (ﷺ). This is the opinion of al-Thawri}}
\hadithdefcmd{abudawud}{1237}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِأَصْحَابِهِ فِي خَوْفٍ فَجَعَلَهُمْ خَلْفَهُ صَفَّيْنِ فَصَلَّى بِالَّذِينَ يَلُونَهُ رَكْعَةً ثُمَّ قَامَ فَلَمْ يَزَلْ قَائِمًا حَتَّى صَلَّى الَّذِينَ خَلْفَهُمْ رَكْعَةً ثُمَّ تَقَدَّمُوا وَتَأَخَّرَ الَّذِينَ كَانُوا قُدَّامَهُمْ فَصَلَّى بِهِمُ النَّبِيُّ صلى الله عليه وسلم رَكْعَةً ثُمَّ قَعَدَ حَتَّى صَلَّى الَّذِينَ تَخَلَّفُوا رَكْعَةً ثُمَّ سَلَّمَ ‏.‏\hadithno{1237}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4131) Sahih Muslim (841)}\hadithtrans{Narrated Sahl b. Abi Hathmah:The Prophet (ﷺ) prayed in time of danger and divided them (the people) behind him in two rows. He then led those who were near him in one rak'ah. Then he stood and remained standing till those who were in second row offered one rak'ah. Thereafter they came forward and those who were in front of them (in the first row) stepped backward. The Prophet (ﷺ) led them in one rak'ah of prayer. He sat down till those who were in the second row completed on rak'ah. He then uttered the salutation}}
\hadithdefcmd{abudawud}{1238}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، عَمَّنْ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ ذَاتِ الرِّقَاعِ صَلاَةَ الْخَوْفِ أَنَّ طَائِفَةً صَفَّتْ مَعَهُ وَطَائِفَةً وِجَاهَ الْعَدُوِّ فَصَلَّى بِالَّتِي مَعَهُ رَكْعَةً ثُمَّ ثَبَتَ قَائِمًا وَأَتَمُّوا لأَنْفُسِهِمْ ثُمَّ انْصَرَفُوا وَصَفُّوا وِجَاهَ الْعَدُوِّ وَجَاءَتِ الطَّائِفَةُ الأُخْرَى فَصَلَّى بِهِمُ الرَّكْعَةَ الَّتِي بَقِيَتْ مِنْ صَلاَتِهِ ثُمَّ ثَبَتَ جَالِسًا وَأَتَمُّوا لأَنْفُسِهِمْ ثُمَّ سَلَّمَ بِهِمْ ‏.‏ قَالَ مَالِكٌ وَحَدِيثُ يَزِيدَ بْنِ رُومَانَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ ‏.‏\hadithno{1238}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4129) Sahih Muslim (842)}\hadithtrans{Narrated Salih b. Khawwat: On the authority of a person who offered the prayer in time of danger along with the Messenger of Allah (ﷺ) at the battle of Dhat al-Riqa. One section of people stood in the row of prayer along with the Messenger of Allah (ﷺ) and the other section remained standing in front of the enemy. He led those who were with him in one rak'ah and remained standing (in his place) and they completed (the second rak'ah) by themselves. Then they turned away and arrayed before the enemy. Thereafter the other section came and he led them in the rak'ah which remained from his prayer. He then remained sitting (in his place) and they completed their one rak'ah by themselves. He then uttered the salutation along with them. Malik said: I like the tradition reported by Yazid b. Ruman (i.e. the present tradition) more than (other versions) I heard}}
\hadithdefcmd{abudawud}{1239}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ صَالِحِ بْنِ خَوَّاتٍ الأَنْصَارِيِّ، أَنَّ سَهْلَ بْنَ أَبِي حَثْمَةَ الأَنْصَارِيَّ، حَدَّثَهُ أَنَّ صَلاَةَ الْخَوْفِ أَنْ يَقُومَ الإِمَامُ وَطَائِفَةٌ مِنْ أَصْحَابِهِ وَطَائِفَةٌ مُوَاجِهَةَ الْعَدُوِّ فَيَرْكَعُ الإِمَامُ رَكْعَةً وَيَسْجُدُ بِالَّذِينَ مَعَهُ ثُمَّ يَقُومُ فَإِذَا اسْتَوَى قَائِمًا ثَبَتَ قَائِمًا وَأَتَمُّوا لأَنْفُسِهِمُ الرَّكْعَةَ الْبَاقِيَةَ ثُمَّ سَلَّمُوا وَانْصَرَفُوا وَالإِمَامُ قَائِمٌ فَكَانُوا وِجَاهَ الْعَدُوِّ ثُمَّ يُقْبِلُ الآخَرُونَ الَّذِينَ لَمْ يُصَلُّوا فَيُكَبِّرُونَ وَرَاءَ الإِمَامِ فَيَرْكَعُ بِهِمْ وَيَسْجُدُ بِهِمْ ثُمَّ يُسَلِّمُ فَيَقُومُونَ فَيَرْكَعُونَ لأَنْفُسِهِمُ الرَّكْعَةَ الْبَاقِيَةَ ثُمَّ يُسَلِّمُونَ ‏.‏ قَالَ أَبُو دَاوُدَ وَأَمَّا رِوَايَةُ يَحْيَى بْنِ سَعِيدٍ عَنِ الْقَاسِمِ نَحْوُ رِوَايَةِ يَزِيدَ بْنِ رُومَانَ إِلاَّ أَنَّهُ خَالَفَهُ فِي السَّلاَمِ وَرِوَايَةُ عُبَيْدِ اللَّهِ نَحْوُ رِوَايَةِ يَحْيَى بْنِ سَعِيدٍ قَالَ وَيَثْبُتُ قَائِمًا ‏.‏\hadithno{1239}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4129) Sahih Muslim (842)}\hadithtrans{Narrated Sahl b. Abi Hathmah al-Ansari: The prayer time of danger should be offered in the following way: The imam should stand (for prayer) and a section of the people should stand along with him. The other section should stand facing the enemy. The imam should perform bowing and prostrate himself along with those who are with him. He then should stand (after prostration) and, when he stands straight, he should remain standing. They (the people) should (in the meantime) complete their remaining rak'ah (i.e. the second one). They they should utter the salutation, and turn away while the imam should remain standing. They should go before the enemy. Thereafter those who did not pray should come forward and utter the takbir (Allah is most great) behind imam. He should bow and prostrate along with them and utter the salutation. Then they should stand and completed their remaining rak'ah, and utter the salutation. Abu Dawud said: The tradition reported by Yahya b. Sa'id from al-Qasim is similar to the one transmitted by Yazid b. Ruman except that he differed with him in salutation. The tradition reported by 'Ubaid Allah is like the one reported by Yahya b. Sa'id, saying: He (the Prophet) remained standing}}
\hadithdefcmd{abudawud}{1240}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ الْمُقْرِئُ، حَدَّثَنَا حَيْوَةُ، وَابْنُ، لَهِيعَةَ قَالاَ أَخْبَرَنَا أَبُو الأَسْوَدِ، أَنَّهُ سَمِعَ عُرْوَةَ بْنَ الزُّبَيْرِ، يُحَدِّثُ عَنْ مَرْوَانَ بْنِ الْحَكَمِ، أَنَّهُ سَأَلَ أَبَا هُرَيْرَةَ هَلْ صَلَّيْتَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ قَالَ أَبُو هُرَيْرَةَ نَعَمْ ‏.‏ قَالَ مَرْوَانُ مَتَى فَقَالَ أَبُو هُرَيْرَةَ عَامَ غَزْوَةِ نَجْدٍ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى صَلاَةِ الْعَصْرِ فَقَامَتْ مَعَهُ طَائِفَةٌ وَطَائِفَةٌ أُخْرَى مُقَابِلَ الْعَدُوِّ ظُهُورُهُمْ إِلَى الْقِبْلَةِ فَكَبَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَبَّرُوا جَمِيعًا الَّذِينَ مَعَهُ وَالَّذِينَ مُقَابِلِي الْعَدُوِّ ثُمَّ رَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَةً وَاحِدَةً وَرَكَعَتِ الطَّائِفَةُ الَّتِي مَعَهُ ثُمَّ سَجَدَ فَسَجَدَتِ الطَّائِفَةُ الَّتِي تَلِيهِ وَالآخَرُونَ قِيَامٌ مُقَابِلِي الْعَدُوِّ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَامَتِ الطَّائِفَةُ الَّتِي مَعَهُ فَذَهَبُوا إِلَى الْعَدُوِّ فَقَابَلُوهُمْ وَأَقْبَلَتِ الطَّائِفَةُ الَّتِي كَانَتْ مُقَابِلِي الْعَدُوِّ فَرَكَعُوا وَسَجَدُوا وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ كَمَا هُوَ ثُمَّ قَامُوا فَرَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَةً أُخْرَى وَرَكَعُوا مَعَهُ وَسَجَدَ وَسَجَدُوا مَعَهُ ثُمَّ أَقْبَلَتِ الطَّائِفَةُ الَّتِي كَانَتْ مُقَابِلِي الْعَدُوِّ فَرَكَعُوا وَسَجَدُوا وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَاعِدٌ وَمَنْ مَعَهُ ثُمَّ كَانَ السَّلاَمُ فَسَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَلَّمُوا جَمِيعًا فَكَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم رَكْعَتَانِ وَلِكُلِّ رَجُلٍ مِنَ الطَّائِفَتَيْنِ رَكْعَةٌ رَكْعَةٌ ‏.‏\hadithno{1240}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Urwah ibn az-Zubayr reported that Marwan ibn al-Hakam asked AbuHurayrah:Did you pray in time of danger with the Messenger of Allah (ﷺ)? AbuHurayrah replied: Yes. Marwan then asked: When? AbuHurayrah said: On the occasion of the Battle of Najd. The Messenger of Allah (ﷺ) stood up to offer the afternoon prayer. One section stood with him (to pray) and the other was standing before the enemy, and their backs were towards the qiblah. The Messenger of Allah (ﷺ) uttered the takbir and all of them too uttered the takbir, i.e. those who were with him and those who were facing the enemy. Then the Messenger of Allah (ﷺ) offered one rak'ah and the section that was with him also prayed one rak'ah. He then prostrated himself and those who were with him also prostrated, while the other section was standing before the enemy. The Messenger of Allah (ﷺ) then stood up and the section with him also stood up. They went and faced the enemy and the section that was previously facing the enemy stepped forward. They bowed and prostrated while the Messenger of Allah (ﷺ) was standing in the same position. Then they stood up and the Messenger of Allah (may peace be upon) prayed another rak'ah and all of them bowed and prostrated along with him. After that the section that was standing before the enemy came forward and they bowed and prostrated, while the Messenger of Allah (ﷺ) remained seated and also those who were with him. The salutation then followed. The Messenger of Allah (ﷺ) uttered the salutation and all of them uttered it together. The Messenger of Allah (ﷺ) prayed two rak'ahs and each of the two sections prayed one rak'ah with him (and the other by themselves)}}
\hadithdefcmd{abudawud}{1241}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، حَدَّثَنَا سَلَمَةُ، حَدَّثَنِي مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، وَمُحَمَّدِ بْنِ الأَسْوَدِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى نَجْدٍ حَتَّى إِذَا كُنَّا بِذَاتِ الرِّقَاعِ مِنْ نَخْلٍ لَقِيَ جَمْعًا مِنْ غَطَفَانَ فَذَكَرَ مَعْنَاهُ وَلَفْظُهُ عَلَى غَيْرِ لَفْظِ حَيْوَةَ وَقَالَ فِيهِ حِينَ رَكَعَ بِمَنْ مَعَهُ وَسَجَدَ قَالَ فَلَمَّا قَامُوا مَشَوُا الْقَهْقَرَى إِلَى مَصَافِّ أَصْحَابِهِمْ وَلَمْ يَذْكُرِ اسْتِدْبَارَ الْقِبْلَةِ ‏.‏\hadithno{1241}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Hurairah: We went out with the Messenger of Allah (ﷺ) to Najd. When we reached Dhat ar-Riqa at Nakhl (or in a valley with palm trees) he met a group of the tribe of Ghatafan. The narrator then reported the tradition to the same effect, but his version is other than that of Haywah. He added to the words "when he bowed along with those who were with him and prostrated" the words "when they stood up, they retraced their footsteps to the rows of their companions". He did not mention the words "their back was towards the qiblah}}
\hadithdefcmd{abudawud}{1242}{قَالَ أَبُو دَاوُدَ وَأَمَّا عُبَيْدُ اللَّهِ بْنُ سَعْدٍ فَحَدَّثَنَا قَالَ حَدَّثَنِي عَمِّي، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرِ بْنِ الزُّبَيْرِ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ عَائِشَةَ حَدَّثَتْهُ بِهَذِهِ الْقِصَّةِ، قَالَتْ كَبَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَبَّرَتِ الطَّائِفَةُ الَّذِينَ صُفُّوا مَعَهُ ثُمَّ رَكَعَ فَرَكَعُوا ثُمَّ سَجَدَ فَسَجَدُوا ثُمَّ رَفَعَ فَرَفَعُوا ثُمَّ مَكَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسًا ثُمَّ سَجَدُوا هُمْ لأَنْفُسِهِمُ الثَّانِيَةَ ثُمَّ قَامُوا فَنَكَصُوا عَلَى أَعْقَابِهِمْ يَمْشُونَ الْقَهْقَرَى حَتَّى قَامُوا مِنْ وَرَائِهِمْ وَجَاءَتِ الطَّائِفَةُ الأُخْرَى فَقَامُوا فَكَبَّرُوا ثُمَّ رَكَعُوا لأَنْفُسِهِمْ ثُمَّ سَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَجَدُوا مَعَهُ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَجَدُوا لأَنْفُسِهِمُ الثَّانِيَةَ ثُمَّ قَامَتِ الطَّائِفَتَانِ جَمِيعًا فَصَلُّوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَكَعَ فَرَكَعُوا ثُمَّ سَجَدَ فَسَجَدُوا جَمِيعًا ثُمَّ عَادَ فَسَجَدَ الثَّانِيَةَ وَسَجَدُوا مَعَهُ سَرِيعًا كَأَسْرَعِ الإِسْرَاعِ جَاهِدًا لاَ يَأْلُونَ سِرَاعًا ثُمَّ سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَلَّمُوا فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ شَارَكَهُ النَّاسُ فِي الصَّلاَةِ كُلِّهَا ‏.‏\hadithno{1242}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Dawud said:This tradition has been transmitted by 'Aishah through a different chain of narrators. She said: The Messenger of Allah (ﷺ) uttered the takbir and the section that was in the same row with him also uttered the takbir. He then bowed and they also bowed, and he prostrated and they also prostrated. Then he raised his head and they also raised (their heads). The Messenger of Allah (ﷺ) then remained seated. They prostrated alone and stood up and retraced their footsteps and stood behind them. Then the other section came; they stood up and uttered the takbir and bowed by themselves. The Messenger of Allah (ﷺ) prostrated himself and they also prostrated with him. Then the Messenger of Allah (ﷺ) stood up and they performed the second prostration by themselves. Then both the sections stood up and prayed with the Messenger of Allah (ﷺ). He bowed and they also bowed, and then he prostrated himself and they also prostrated themselves. Then he returned and performed the second prostration and they also prostrated with him as quickly as possible, showing no slackness in quick prostration. The Messenger of Allah (ﷺ) then uttered the salutation. After that the Messenger of Allah (ﷺ) stood up. Thus everyone participated in the entire prayer}}
\hadithdefcmd{abudawud}{1243}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِإِحْدَى الطَّائِفَتَيْنِ رَكْعَةً وَالطَّائِفَةُ الأُخْرَى مُوَاجِهَةُ الْعَدُوِّ ثُمَّ انْصَرَفُوا فَقَامُوا فِي مَقَامِ أُولَئِكَ وَجَاءَ أُولَئِكَ فَصَلَّى بِهِمْ رَكْعَةً أُخْرَى ثُمَّ سَلَّمَ عَلَيْهِمْ ثُمَّ قَامَ هَؤُلاَءِ فَقَضَوْا رَكْعَتَهُمْ وَقَامَ هَؤُلاَءِ فَقَضَوْا رَكْعَتَهُمْ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ نَافِعٌ وَخَالِدُ بْنُ مَعْدَانَ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَكَذَلِكَ قَوْلُ مَسْرُوقٍ وَيُوسُفَ بْنِ مِهْرَانَ عَنِ ابْنِ عَبَّاسٍ وَكَذَلِكَ رَوَى يُونُسُ عَنِ الْحَسَنِ عَنْ أَبِي مُوسَى أَنَّهُ فَعَلَهُ ‏.‏\hadithno{1243}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4133) Sahih Muslim (839)}\hadithtrans{Narrated Ibn 'Umar: The Messenger of Allah (ﷺ) led one section in one rak'ah of prayer and the other section was facing the enemy. Then they turned away and took the position of the other section. They (the other section) came and he (the Prophet) led them in the second rak'ah. He then uttered the salutation. Thereafter they stood up and completed the remaining rak'ah, they went away and the other section completed their remaining rak'ah. Abu Dawud said: This tradition has been narrated by Nafi' and Khalid b. Ma'dan from Ibn 'Umar in like manner from the Prophet (ﷺ). This has also been transmitted similarly by Masruq ad Yusuf b. Mihran on the authority of Ibn 'Abbas. This has been narrated by Yunus from al-Hasan from Abu Musa something similarly, saying that Abu Musa has done so}}
\hadithdefcmd{abudawud}{1244}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا خُصَيْفٌ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فَقَامُوا صَفَّيْنِ صَفٌّ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَصَفٌّ مُسْتَقْبِلَ الْعَدُوِّ فَصَلَّى بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَةً ثُمَّ جَاءَ الآخَرُونَ فَقَامُوا مَقَامَهُمْ وَاسْتَقْبَلَ هَؤُلاَءِ الْعَدُوَّ فَصَلَّى بِهِمُ النَّبِيُّ صلى الله عليه وسلم رَكْعَةً ثُمَّ سَلَّمَ فَقَامَ هَؤُلاَءِ فَصَلَّوْا لأَنْفُسِهِمْ رَكْعَةً ثُمَّ سَلَّمُوا ثُمَّ ذَهَبُوا فَقَامُوا مَقَامَ أُولَئِكَ مُسْتَقْبِلِي الْعَدُوِّ وَرَجَعَ أُولَئِكَ إِلَى مَقَامِهِمْ فَصَلَّوْا لأَنْفُسِهِمْ رَكْعَةً ثُمَّ سَلَّمُوا ‏.‏\hadithno{1244}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Messenger of Allah (ﷺ) led us in prayer in the time of danger. They (the people) stood in two rows. One row was behind the Messenger of Allah (ﷺ) and the other faced the enemy. The Messenger of Allah (ﷺ) led them in one rak'ah,and then the other section came and took their place; they went and faced the enemy. The Prophet (ﷺ) led them in one rak'ah and uttered the salutation. They stood up and prayed the second rak'ah by themselves and uttered the salutation and went away; they took the place of the other section facing the enemy. They came back and took their place. They prayed one rak'ah by themselves and then uttered the salutation}}
\hadithdefcmd{abudawud}{1245}{حَدَّثَنَا تَمِيمُ بْنُ الْمُنْتَصِرِ، أَخْبَرَنَا إِسْحَاقُ، - يَعْنِي ابْنَ يُوسُفَ - عَنْ شَرِيكٍ، عَنْ خُصَيْفٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏ قَالَ فَكَبَّرَ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَكَبَّرَ الصَّفَّانِ جَمِيعًا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الثَّوْرِيُّ بِهَذَا الْمَعْنَى عَنْ خُصَيْفٍ وَصَلَّى عَبْدُ الرَّحْمَنِ بْنُ سَمُرَةَ هَكَذَا إِلاَّ أَنَّ الطَّائِفَةَ الَّتِي صَلَّى بِهِمْ رَكْعَةً ثُمَّ سَلَّمَ مَضَوْا إِلَى مَقَامِ أَصْحَابِهِمْ وَجَاءَ هَؤُلاَءِ فَصَلَّوْا لأَنْفُسِهِمْ رَكْعَةً ثُمَّ رَجَعُوا إِلَى مَقَامِ أُولَئِكَ فَصَلَّوْا لأَنْفُسِهِمْ رَكْعَةً ‏.‏ قَالَ أَبُو دَاوُدَ حَدَّثَنَا بِذَلِكَ مُسْلِمُ بْنُ إِبْرَاهِيمَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ حَبِيبٍ قَالَ أَخْبَرَنِي أَبِي أَنَّهُمْ غَزَوْا مَعَ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ كَابُلَ فَصَلَّى بِنَا صَلاَةَ الْخَوْفِ ‏.‏\hadithno{1245}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{This tradition has been transmitted by Kushaif with a different chain of narrators and to the same effect. This version adds:The Prophet of Allah (ﷺ) uttered takbir and both rows uttered takbir together. Abu Dawud said: This tradition has been narrated by al-Thawri to the same effect on the authority of Khusaif. 'Abd al-Rahman b. Samurah also prayed in like manner. But the section which he (the Prophet) led in one rak'ah and then uttered the salutation and went and took the place of their companions. They came and prayed one rak'ah by themselves. Then they returned to their place and they prayed (one rak'ah) by themselves. Abu Dawud said: Muslim b. Ibrahim reported from 'Abd al-Samad b. Habib on the authority of his father that they had fought a battle at Kabul along with 'Abd al-Rahman b. Samurah. He led us in prayer in time of danger}}
\hadithdefcmd{abudawud}{1246}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي الأَشْعَثُ بْنُ سُلَيْمٍ، عَنِ الأَسْوَدِ بْنِ هِلاَلٍ، عَنْ ثَعْلَبَةَ بْنِ زَهْدَمٍ، قَالَ كُنَّا مَعَ سَعِيدِ بْنِ الْعَاصِ بِطَبَرِسْتَانَ فَقَامَ فَقَالَ أَيُّكُمْ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فَقَالَ حُذَيْفَةُ أَنَا فَصَلَّى بِهَؤُلاَءِ رَكْعَةً وَبِهَؤُلاَءِ رَكْعَةً وَلَمْ يَقْضُوا ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا رَوَاهُ عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ وَمُجَاهِدٌ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَعَبْدُ اللَّهِ بْنُ شَقِيقٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَيَزِيدُ الْفَقِيرُ وَأَبُو مُوسَى - قَالَ أَبُو دَاوُدَ رَجُلٌ مِنَ التَّابِعِينَ لَيْسَ بِالأَشْعَرِيِّ - جَمِيعًا عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَدْ قَالَ بَعْضُهُمْ فِي حَدِيثِ يَزِيدَ الْفَقِيرِ إِنَّهُمْ قَضَوْا رَكْعَةً أُخْرَى ‏.‏ وَكَذَلِكَ رَوَاهُ سِمَاكٌ الْحَنَفِيُّ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَكَذَلِكَ رَوَاهُ زَيْدُ بْنُ ثَابِتٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فَكَانَتْ لِلْقَوْمِ رَكْعَةً رَكْعَةً وَلِلنَّبِيِّ صلى الله عليه وسلم رَكْعَتَيْنِ ‏.‏\hadithno{1246}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hudhayfah: Tha'labah ibn Zahdam said: We accompanied Sa'd ibn al-'As at Tabaristan. He stood and said: Which of you prayed along with the Messenger of Allah (ﷺ) in time of danger? Hudhayfah said: I then he led one section in one rak'ah and the other section in one rak'ah. They did not pray the second rak'ah by themselves. Abu Dawud: This tradition has been transmitted by 'Ubaid Allah b. 'Abd Allah and Mujahid on the authority of Ibn 'Abbas from the Prophet (ﷺ) in like manner. This has also been narrated by 'Abd Allah b. Shaqiq from Abu Hurairah from the Prophet (ﷺ). Yazid al-Faqir and Abu Musa also narrated this tradition from Jabir from the Prophet (ﷺ). Some of the narrators said in the version narrated by Yazid al-Faqir that they completed their second rak'ah. This has also been narrated by Simak al-Hanafi on the authority of Ibn 'Umar from the Prophet (ﷺ) something similar. Zaid b. Thabit also narrated from the Prophet (ﷺ) in like manner. This version adds: The people prayed on rak'ah and the Prophet (ﷺ) prayed two rak'ahs}}
\hadithdefcmd{abudawud}{1247}{حَدَّثَنَا مُسَدَّدٌ، وَسَعِيدُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ بُكَيْرِ بْنِ الأَخْنَسِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ فَرَضَ اللَّهُ تَعَالَى الصَّلاَةَ عَلَى لِسَانِ نَبِيِّكُمْ صلى الله عليه وسلم فِي الْحَضَرِ أَرْبَعًا وَفِي السَّفَرِ رَكْعَتَيْنِ وَفِي الْخَوْفِ رَكْعَةً ‏.‏\hadithno{1247}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (687)}\hadithtrans{Narrated Ibn 'Abbas:Allah, the Exalted, prescribed prayer for you, through the tongue of your Prophet (ﷺ), four rak'ahs while resident, two rak'ahs while travelling and one rak'ah in time of danger}}
\hadithdefcmd{abudawud}{1248}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَشْعَثُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم فِي خَوْفٍ الظُّهْرَ فَصَفَّ بَعْضَهُمْ خَلْفَهُ وَبَعْضَهُمْ بِإِزَاءِ الْعَدُوِّ فَصَلَّى بِهِمْ رَكْعَتَيْنِ ثُمَّ سَلَّمَ فَانْطَلَقَ الَّذِينَ صَلَّوْا مَعَهُ فَوَقَفُوا مَوْقِفَ أَصْحَابِهِمْ ثُمَّ جَاءَ أُولَئِكَ فَصَلَّوْا خَلْفَهُ فَصَلَّى بِهِمْ رَكْعَتَيْنِ ثُمَّ سَلَّمَ فَكَانَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَرْبَعًا وَلأَصْحَابِهِ رَكْعَتَيْنِ رَكْعَتَيْنِ ‏.‏ وَبِذَلِكَ كَانَ يُفْتِي الْحَسَنُ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ فِي الْمَغْرِبِ يَكُونُ لِلإِمَامِ سِتَّ رَكَعَاتٍ وَلِلْقَوْمِ ثَلاَثًا ثَلاَثًا ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ يَحْيَى بْنُ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَكَذَلِكَ قَالَ سُلَيْمَانُ الْيَشْكُرِيُّ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1248}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuBakrah: The Prophet (ﷺ) offered the noon prayer in time of danger. Some of the people formed a row behind him and others arrayed themselves against the enemy. He led them in two rak'ahs and then he uttered the salutation. Then those who were with him went away and took the position of their companions before the enemy. Then they came and prayed behind him. He led them in two rak'ahs and uttered the salutation. Thus the Messenger of Allah (ﷺ) offered four rak'ahs and his companions offered two rak'ahs. Al-Hasan used to give legal verdict on the authority of this tradition. Abu Dawud said: This will be so in the sunset prayer. The imam will offer six rak'ahs and the people three rak'ahs. Abu Dawud said: Yahya b. Abi Kathir narrated from Abu Salamah from Jabir from the Prophet (ﷺ) something similar. Sulaiman al-Yashkuri reported it from the Prophet (ﷺ) in like manner}}
\hadithdefcmd{abudawud}{1249}{حَدَّثَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنِ ابْنِ عَبْدِ اللَّهِ بْنِ أُنَيْسٍ، عَنْ أَبِيهِ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى خَالِدِ بْنِ سُفْيَانَ الْهُذَلِيِّ - وَكَانَ نَحْوَ عُرَنَةَ وَعَرَفَاتٍ - فَقَالَ ‏ "‏ اذْهَبْ فَاقْتُلْهُ ‏"‏ ‏.‏ قَالَ فَرَأَيْتُهُ وَحَضَرَتْ صَلاَةُ الْعَصْرِ فَقُلْتُ إِنِّي لأَخَافُ أَنْ يَكُونَ بَيْنِي وَبَيْنَهُ مَا إِنْ أُؤَخِّرُ الصَّلاَةَ فَانْطَلَقْتُ أَمْشِي وَأَنَا أُصَلِّي أُومِئُ إِيمَاءً نَحْوَهُ فَلَمَّا دَنَوْتُ مِنْهُ قَالَ لِي مَنْ أَنْتَ قُلْتُ رَجُلٌ مِنَ الْعَرَبِ بَلَغَنِي أَنَّكَ تَجْمَعُ لِهَذَا الرَّجُلِ فَجِئْتُكَ فِي ذَاكَ ‏.‏ قَالَ إِنِّي لَفِي ذَاكَ فَمَشَيْتُ مَعَهُ سَاعَةً حَتَّى إِذَا أَمْكَنَنِي عَلَوْتُهُ بِسَيْفِي حَتَّى بَرَدَ ‏.‏\hadithno{1249}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Abd Allah b. Unais:The Messenger of Allah (ﷺ) sent me to Khalid b. Sufyan al-Hudhail. This was towards 'Uranah and 'Arafat. He (the Prophet) said: Go and kill him. I saw him when the time of the afternoon prayer had come. I said: I am afraid if a fight takes place between me and him (Khalid b. Sufyan), that might delay the prayer. I proceeded walking towards him while I was praying by making a sign. When I reached near him, he said to me: Who are you ? I replied: A man from the Arabs; it came to me that you were gathering (any army) for this man (i.e. Prophet). Hence I came to you in connection with this matter. He said: I am (engaged) in this (work). I then walked along with him for a while ; when it became convenient for me, I dominated him with my sword until he became cold (dead)}}
